==> aws-cdk.aws-msk-alpha-2.52.0a0.tar.gz: package/lib/cluster-version.d.ts <==
/**
 * Kafka cluster version
 */
export declare class KafkaVersion {
    readonly version: string;
    /**
     * Kafka version 1.1.1
     */
    static readonly V1_1_1: KafkaVersion;
    /**
     * Kafka version 2.2.1
     */
    static readonly V2_2_1: KafkaVersion;
    /**
     * Kafka version 2.3.1
     */
    static readonly V2_3_1: KafkaVersion;
    /**
     * Kafka version 2.4.1
     */
    static readonly V2_4_1_1: KafkaVersion;
    /**
     * Kafka version 2.5.1
     */
    static readonly V2_5_1: KafkaVersion;
    /**
     * Kafka version 2.6.0
     */
    static readonly V2_6_0: KafkaVersion;
    /**
     * Kafka version 2.6.1
     */
    static readonly V2_6_1: KafkaVersion;
    /**
     * Kafka version 2.6.2
     */
    static readonly V2_6_2: KafkaVersion;
    /**
     * Kafka version 2.6.3
     */
    static readonly V2_6_3: KafkaVersion;
    /**
     * Kafka version 2.7.0
     */
    static readonly V2_7_0: KafkaVersion;
    /**
     * Kafka version 2.7.1
     */
    static readonly V2_7_1: KafkaVersion;
    /**
     * Kafka version 2.7.2
     */
    static readonly V2_7_2: KafkaVersion;
    /**
     * Kafka version 2.8.0
     */
    static readonly V2_8_0: KafkaVersion;
    /**
     * Kafka version 2.8.1
     */
    static readonly V2_8_1: KafkaVersion;
    /**
     * Custom cluster version
     * @param version custom version number
     */
    static of(version: string): KafkaVersion;
    /**
     *
     * @param version cluster version number
     */
    private constructor();
}

==> aws-cdk.aws-msk-alpha-2.69.0a0.tar.gz: package/lib/cluster-version.d.ts <==
/**
 * Kafka cluster version
 */
export declare class KafkaVersion {
    readonly version: string;
    /**
     * Kafka version 1.1.1
     */
    static readonly V1_1_1: KafkaVersion;
    /**
     * Kafka version 2.2.1
     */
    static readonly V2_2_1: KafkaVersion;
    /**
     * Kafka version 2.3.1
     */
    static readonly V2_3_1: KafkaVersion;
    /**
     * Kafka version 2.4.1
     */
    static readonly V2_4_1_1: KafkaVersion;
    /**
     * Kafka version 2.5.1
     */
    static readonly V2_5_1: KafkaVersion;
    /**
     * Kafka version 2.6.0
     */
    static readonly V2_6_0: KafkaVersion;
    /**
     * Kafka version 2.6.1
     */
    static readonly V2_6_1: KafkaVersion;
    /**
     * Kafka version 2.6.2
     */
    static readonly V2_6_2: KafkaVersion;
    /**
     * Kafka version 2.6.3
     */
    static readonly V2_6_3: KafkaVersion;
    /**
     * Kafka version 2.7.0
     */
    static readonly V2_7_0: KafkaVersion;
    /**
     * Kafka version 2.7.1
     */
    static readonly V2_7_1: KafkaVersion;
    /**
     * Kafka version 2.7.2
     */
    static readonly V2_7_2: KafkaVersion;
    /**
     * Kafka version 2.8.0
     */
    static readonly V2_8_0: KafkaVersion;
    /**
     * Kafka version 2.8.1
     */
    static readonly V2_8_1: KafkaVersion;
    /**
     * Kafka version 3.1.1
     */
    static readonly V3_1_1: KafkaVersion;
    /**
     * Kafka version 3.2.0
     */
    static readonly V3_2_0: KafkaVersion;
    /**
     * Kafka version 3.3.1
     */
    static readonly V3_3_1: KafkaVersion;
    /**
     * Kafka version 3.3.2
     */
    static readonly V3_3_2: KafkaVersion;
    /**
     * Custom cluster version
     * @param version custom version number
     */
    static of(version: string): KafkaVersion;
    /**
     *
     * @param version cluster version number
     */
    private constructor();
}
